@@ -13,6 +13,7 @@ import (
 	testinghelper "github.com/open-cluster-management/registration-operator/pkg/helpers/testing"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
+	fakeapiextensions "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset/fake"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/meta"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -24,10 +25,11 @@ import (
 )
 
 type testController struct {
-	controller     *klusterletController
-	kubeClient     *fakekube.Clientset
-	operatorClient *fakeoperatorclient.Clientset
-	operatorStore  cache.Store
+	controller         *klusterletController
+	kubeClient         *fakekube.Clientset
+	apiExtensionClient *fakeapiextensions.Clientset
+	operatorClient     *fakeoperatorclient.Clientset
+	operatorStore      cache.Store
 }
 
 func newSecret(name, namespace string) *corev1.Secret {
@@ -86,26 +88,29 @@ func newNamespace(name string) *corev1.Namespace {
 
 func newTestController(klusterlet *opratorapiv1.Klusterlet, objects ...runtime.Object) *testController {
 	fakeKubeClient := fakekube.NewSimpleClientset(objects...)
+	fakeAPIExtensionClient := fakeapiextensions.NewSimpleClientset()
 	fakeOperatorClient := fakeoperatorclient.NewSimpleClientset(klusterlet)
 	operatorInformers := operatorinformers.NewSharedInformerFactory(fakeOperatorClient, 5*time.Minute)
 	kubeVersion, _ := version.ParseGeneric("v1.18.0")
 
 	hubController := &klusterletController{
-		klusterletClient:  fakeOperatorClient.OperatorV1().Klusterlets(),
-		kubeClient:        fakeKubeClient,
-		klusterletLister:  operatorInformers.Operator().V1().Klusterlets().Lister(),
-		kubeVersion:       kubeVersion,
-		operatorNamespace: "open-cluster-management",
+		klusterletClient:   fakeOperatorClient.OperatorV1().Klusterlets(),
+		kubeClient:         fakeKubeClient,
+		apiExtensionClient: fakeAPIExtensionClient,
+		klusterletLister:   operatorInformers.Operator().V1().Klusterlets().Lister(),
+		kubeVersion:        kubeVersion,
+		operatorNamespace:  "open-cluster-management",
 	}
 
 	store := operatorInformers.Operator().V1().Klusterlets().Informer().GetStore()
 	store.Add(klusterlet)
 
 	return &testController{
-		controller:     hubController,
-		kubeClient:     fakeKubeClient,
-		operatorClient: fakeOperatorClient,
-		operatorStore:  store,
+		controller:         hubController,
+		kubeClient:         fakeKubeClient,
+		apiExtensionClient: fakeAPIExtensionClient,
+		operatorClient:     fakeOperatorClient,
+		operatorStore:      store,
 	}
 }
 
@@ -229,8 +234,8 @@ func ensureObject(t *testing.T, object runtime.Object, klusterlet *opratorapiv1.
 // TestSyncDeploy test deployment of klusterlet components
 func TestSyncDeploy(t *testing.T) {
 	klusterlet := newKlusterlet("klusterlet", "testns", "cluster1")
-	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfigSecret, "testns")
-	hubKubeConfigSecret := newSecret(helpers.HubKubeConfigSecret, "testns")
+	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfig, "testns")
+	hubKubeConfigSecret := newSecret(helpers.HubKubeConfig, "testns")
 	hubKubeConfigSecret.Data["kubeconfig"] = []byte("dummuykubeconnfig")
 	namespace := newNamespace("testns")
 	controller := newTestController(klusterlet, bootStrapSecret, hubKubeConfigSecret, namespace)
@@ -258,6 +263,18 @@ func TestSyncDeploy(t *testing.T) {
 		ensureObject(t, object, klusterlet)
 	}
 
+	apiExtenstionAction := controller.apiExtensionClient.Actions()
+	createCRDObjects := []runtime.Object{}
+	for _, action := range apiExtenstionAction {
+		if action.GetVerb() == "create" && action.GetResource().Resource == "customresourcedefinitions" {
+			object := action.(clienttesting.CreateActionImpl).Object
+			createCRDObjects = append(createCRDObjects, object)
+		}
+	}
+	if len(createCRDObjects) != 1 {
+		t.Errorf("Expect 1 objects created in the sync loop, actual %d", len(createCRDObjects))
+	}
+
 	operatorAction := controller.operatorClient.Actions()
 	if len(operatorAction) != 2 {
 		t.Errorf("Expect 2 actions in the sync loop, actual %#v", operatorAction)
@@ -293,8 +310,21 @@ func TestSyncDelete(t *testing.T) {
 		}
 	}
 
-	if len(kubeActions) != 12 {
-		t.Errorf("Expected 12 delete actions, but got %d", len(kubeActions))
+	if len(kubeActions) != 13 {
+		t.Errorf("Expected 13 delete actions, but got %d", len(kubeActions))
+	}
+
+	deleteCRDActions := []clienttesting.DeleteActionImpl{}
+	crdActions := controller.apiExtensionClient.Actions()
+	for _, action := range crdActions {
+		if action.GetVerb() == "delete" {
+			deleteAction := action.(clienttesting.DeleteActionImpl)
+			deleteActions = append(deleteCRDActions, deleteAction)
+		}
+	}
+
+	if len(crdActions) != 0 {
+		t.Errorf("Expected 0 delete actions, but got %d", len(crdActions))
 	}
 }
 
@@ -345,8 +375,8 @@ func TestGetServersFromKlusterlet(t *testing.T) {
 func TestClusterNameChange(t *testing.T) {
 	klusterlet := newKlusterlet("klusterlet", "testns", "cluster1")
 	namespace := newNamespace("testns")
-	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfigSecret, "testns")
-	hubSecret := newSecret(helpers.HubKubeConfigSecret, "testns")
+	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfig, "testns")
+	hubSecret := newSecret(helpers.HubKubeConfig, "testns")
 	hubSecret.Data["kubeconfig"] = []byte("dummuykubeconnfig")
 	hubSecret.Data["cluster-name"] = []byte("cluster1")
 	controller := newTestController(klusterlet, bootStrapSecret, hubSecret, namespace)
@@ -394,9 +424,9 @@ func TestClusterNameChange(t *testing.T) {
 		}
 
 		getAction := action.(clienttesting.GetActionImpl)
-		if getAction.Name != helpers.HubKubeConfigSecret {
+		if getAction.Name != helpers.HubKubeConfig {
 			return false, nil, errors.NewNotFound(
-				corev1.Resource("secrets"), helpers.HubKubeConfigSecret)
+				corev1.Resource("secrets"), helpers.HubKubeConfig)
 		}
 		return true, hubSecret, nil
 	})
@@ -425,8 +455,8 @@ func TestClusterNameChange(t *testing.T) {
 
 func TestSyncWithPullSecret(t *testing.T) {
 	klusterlet := newKlusterlet("klusterlet", "testns", "cluster1")
-	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfigSecret, "testns")
-	hubKubeConfigSecret := newSecret(helpers.HubKubeConfigSecret, "testns")
+	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfig, "testns")
+	hubKubeConfigSecret := newSecret(helpers.HubKubeConfig, "testns")
 	hubKubeConfigSecret.Data["kubeconfig"] = []byte("dummuykubeconnfig")
 	namespace := newNamespace("testns")
 	pullSecret := newSecret(imagePullSecret, "open-cluster-management")
@@ -454,8 +484,8 @@ func TestSyncWithPullSecret(t *testing.T) {
 
 func TestDeployOnKube111(t *testing.T) {
 	klusterlet := newKlusterlet("klusterlet", "testns", "cluster1")
-	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfigSecret, "testns")
-	hubKubeConfigSecret := newSecret(helpers.HubKubeConfigSecret, "testns")
+	bootStrapSecret := newSecret(helpers.BootstrapHubKubeConfig, "testns")
+	hubKubeConfigSecret := newSecret(helpers.HubKubeConfig, "testns")
 	hubKubeConfigSecret.Data["kubeconfig"] = []byte("dummuykubeconnfig")
 	namespace := newNamespace("testns")
 	controller := newTestController(klusterlet, bootStrapSecret, hubKubeConfigSecret, namespace)
@@ -515,7 +545,7 @@ func TestDeployOnKube111(t *testing.T) {
 		}
 	}
 
-	if len(kubeActions) != 14 {
-		t.Errorf("Expected 14 delete actions, but got %d", len(kubeActions))
+	if len(kubeActions) != 15 {
+		t.Errorf("Expected 15 delete actions, but got %d", len(kubeActions))
 	}
 }
